@@ -53,35 +53,22 @@
    a TabBar with n Tabs (at least one per soundcard). These contain View's with sliders, switches and other GUI elements visualizing the Mixer)
 */
 KMixerWidget::KMixerWidget( Mixer *mixer,
-                            QWidget * parent, ViewBase::ViewFlags vflags, GUIProfile* guiprof,
+                            QWidget * parent, ViewBase::ViewFlags vflags, QString guiprofId,
                             KActionCollection* actionCollection )
    : QWidget( parent ), _mixer(mixer),
-     m_topLayout(0), _guiprof(guiprof),
+     m_topLayout(0), _guiprofId(guiprofId),
      _actionCollection(actionCollection)
 {
-	_mainWindow = parent;
-	//kDebug() << "kmixWindow created: parent=" << parent << ", parentWidget()=" << parentWidget();
-   if ( _mixer )
-   {
-      createLayout(vflags);
-   }
-   else
-   {
-      // No mixer found
-      // This is normally never shown. Only if the application
-      // creates an invalid KMixerWidget (but this would actually be
-      // a programming error).
-      QBoxLayout *layout = new QHBoxLayout( this );
-      QString s = i18n("Invalid mixer");
-      QLabel *errorLabel = new QLabel( s, this );
-      errorLabel->setAlignment( Qt::AlignCenter );
-      errorLabel->setWordWrap( true );
-      layout->addWidget( errorLabel );
-   }
+	createLayout(vflags);
 }
 
 KMixerWidget::~KMixerWidget()
 {
+  foreach (ViewBase *view, _views)
+  {
+    delete view;
+  }
+  _views.clear();
 }
 
 /**
@@ -91,7 +78,7 @@ void KMixerWidget::createLayout(ViewBase::ViewFlags vflags)
 {
    // delete old objects
    delete m_topLayout;
-
+  
    // create main layout
    m_topLayout = new QVBoxLayout( this );
    m_topLayout->setSpacing( 3 );
@@ -104,13 +91,18 @@ void KMixerWidget::createLayout(ViewBase::ViewFlags vflags)
    * 2b) Create device widgets
    * 2c) Add Views to Tab
    ********************************************************************/
-   ViewSliders* view = new ViewSliders( this, _guiprof->getId().toLatin1(), _mixer, vflags, _guiprof, _actionCollection );
-   possiblyAddView(view);
-   show();
-   //    kDebug(67100) << "KMixerWidget::createLayout(): EXIT\n";
+   GUIProfile* guiprof = getGuiprof();
+   if ( guiprof != 0 )
+   {
+    kDebug() << "Add a view " << _guiprofId;
+    ViewSliders* view = new ViewSliders( this, guiprof->getId(), _mixer, vflags, _guiprofId, _actionCollection );
+    possiblyAddView(view);
+   }
+    show();
 }
 
 
+
 /**
  * Add the given view, if it is valid - it must have controls or at least have the chance to gain some (dynamic views)
  * @param vbase
@@ -123,55 +115,18 @@ bool KMixerWidget::possiblyAddView(ViewBase* vbase)
       return false;
    }
    else {
-      vbase->createDeviceWidgets();
       m_topLayout->addWidget(vbase);
       _views.push_back(vbase);
       connect( vbase, SIGNAL(toggleMenuBar()), parentWidget(), SLOT(toggleMenuBar()) );
-      // *this will be deleted on rebuildGUI(), so lets queue the signal
-      connect( vbase, SIGNAL(rebuildGUI())   , parentWidget(), SLOT(recreateGUIwithSavingView()), Qt::QueuedConnection );
-      //connect( vbase, SIGNAL(redrawMixer(QString)), parentWidget(), SLOT(redrawMixer(QString)), Qt::QueuedConnection );
-
       kDebug() << "CONNECT ViewBase count " << vbase->getMixers().size();
-	  foreach ( Mixer* mixer, vbase->getMixers() )
-	  {
-	    kDebug(67100) << "CONNECT ViewBase controlschanged" << mixer->id();
-	   connect ( mixer, SIGNAL(controlChanged()), this, SLOT(refreshVolumeLevelsToplevel()) );
-	   connect ( mixer, SIGNAL(controlsReconfigured(QString)), this, SLOT(controlsReconfiguredToplevel(QString)) );
-	  }
       return true;
    }
 }
 
-void KMixerWidget::controlsReconfiguredToplevel(QString mixerId)
-{
-	foreach ( ViewBase* vbase, _views)
-	{
-		vbase->controlsReconfigured(mixerId);
-	}
-	KMixWindow* kmixWindow = qobject_cast<KMixWindow*>(_mainWindow);
-	kDebug() << "kmixWindow to redraw: " << kmixWindow << ", not-casted=" << _mainWindow;
-	if (kmixWindow != 0)
-	{
-		kmixWindow->redrawMixer(mixerId);
-	}
-	//The dock is updated to show the change in the master channel
-	//This solves the bug id:290177 and problems stated in review #105422
-	kmixWindow->updateDocking();
-}
-
-void KMixerWidget::refreshVolumeLevelsToplevel()
-{
-	foreach ( ViewBase* vbase, _views)
-	{
-		vbase->refreshVolumeLevels();
-	}
-}
-
-
 /**
  * Returns the current View. Normally we have only one View, so we always return the first view.
- * This method is only here for one reason: We can plug in an action in the main menu, so that
- * 99% of all users will be well served. Those who hack their own XML Profile to contain more than one view
+ * This method is only here for one reason: We can plug in an action in the main menu for the view, so that
+ * 99,99% of all users will be well served. Those who hack their own XML Profile to contain more than one view
   must  use the context menu for configuring the additional views.
  */
 ViewBase* KMixerWidget::currentView()
@@ -189,28 +144,7 @@ const std::vector<ViewBase*>::const_iterator viewsEnd = _views.end();
     } // for all tabs
 }
 
-void KMixerWidget::setLabels( bool on )
-{
-    const std::vector<ViewBase*>::const_iterator viewsEnd = _views.end();
-    for ( std::vector<ViewBase*>::const_iterator it = _views.begin(); it != viewsEnd; ++it) {
-        ViewBase* mixerWidget = *it;
-        mixerWidget->setLabels(on);
-    } // for all tabs
-//    }
-}
 
-void KMixerWidget::setTicks( bool on )
-{
-    const std::vector<ViewBase*>::const_iterator viewsEnd = _views.end();
-    for ( std::vector<ViewBase*>::const_iterator it = _views.begin(); it != viewsEnd; ++it) {
-        ViewBase* mixerWidget = *it;
-        mixerWidget->setTicks(on);
-    } // for all tabs
-}
-
-
-/**
- */
 void KMixerWidget::loadConfig( KConfig *config )
 {
    kDebug(67100) << "KMixerWidget::loadConfig()";
@@ -241,16 +175,4 @@ void KMixerWidget::toggleMenuBarSlot() {
     emit toggleMenuBar();
 }
 
-/*
-// in RTL mode, the slider is reversed, we cannot just connect the signal to setBalance()
-// hack around it before calling _mixer->setBalance()
-void KMixerWidget::balanceChanged(int balance)
-{
-    if (QApplication::isRightToLeft())
-        balance = -balance;
-
-    _mixer->setBalance( balance );
-}
-*/
-
 #include "kmixerwidget.moc"
